ByteReader

Struct ByteReader 

pub struct ByteReader<'a> { /* private fields */ }
Interface to safely read plain data which implements FromBytes from a u8 slice

Implementations

Source

impl<'a> ByteReader<'a>

pub fn new(bytes: &'a [u8]) -> Self

Creates a new ByteReader over the specified bytes.

pub fn new_with_rel(bytes: &'a [u8], pos: usize) -> Self

Creates a new relative ByteReader over the specified bytes.

All operations including RVA’s will be relative to the specified position.

pub fn bytes(&self) -> &'a [u8]

Returns a reference to the bytes of this ByteReader.

pub fn remaining_bytes(&self) -> &'a [u8]

Returns a reference to the remaining bytes of this ByteReader.

pub fn bytes_at(&self, pos: usize) -> Result<&'a [u8]>

Returns a reference to the bytes of this ByteReader, starting at the specified position

Errors

This function will return Error::InsufficientBuffer if the specified position is outside of the buffers bounds.

pub fn rel_pos(&self) -> Option<usize>

Returns the relative position set by ByteReader::new_with_rel of this ByteReader.

pub fn pos_to_rel(&self, pos: usize) -> usize

Converts the specified RVA to a position within the buffer

pub fn skip_to(&mut self, pos: Pos) -> &mut Self

Advances the internal data buffer to the specified position

pub fn read<T>(&mut self) -> Result<&'a T>
where T: FromBytes,

Reads a plain data structure implementing FromBytes from the current position

Errors

This function will return an error if the current position is invalid or the bytes at the current position do not have the right memory layout for the requested structure

pub fn read_at<T>(&self, pos: usize) -> Result<&'a T>
where T: FromBytes,

Reads a plain data structure implementing FromBytes from the specified position

Errors

This function will return an error if the specified position is invalid or the bytes at the current position do not have the right memory layout for the requested structure